@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
 
 from ..backdoor_defense import BackdoorDefense
 from trojanvision.environ import env
-from trojanvision.utils import total_variation
+from trojanvision.utils.loss import total_variation
 from trojanvision.utils.ssim import SSIM
 from trojanzoo.utils import normalize_mad, jaccard_idx
 from trojanzoo.utils import to_tensor, to_numpy, tanh_func
@@ -118,7 +118,7 @@ class ABS(BackdoorDefense):
                 self.attack.mark.alpha_mask = mask
                 self.attack.mark.mask = torch.ones_like(mark, dtype=torch.bool)
                 self.attack.target_class = label
-                attack_loss, attack_acc, _ = self.model._validate(
+                attack_loss, attack_acc = self.model._validate(
                     verbose=False, get_data_fn=self.attack.get_data, keep_org=False)
                 _dict['loss'] = loss
                 _dict['attack_acc'] = attack_acc
